@@ -1,3 +1,7 @@
+"""
+The output of the signald's "protocol" request only covers signald's v1 requests.
+This module adds few bindings for v0 requests that should be useful.
+"""
 import asyncio
 import typing
 
@@ -10,6 +14,14 @@ class SignaldAPI(SignaldGeneratedAPI):
     async def get_response_and_wait_for(
         self, request: dict, validator: typing.Callable
     ):
+        """
+        Some API v0 calls actually triggers 2 separate events, so this
+        method allows to easily await for both.
+
+        :param request: The JSON request, as python dict
+        :param validator: A callable that will receive all subsequent
+            to identify the expected second response.
+        """
         future = self.get_future_for(validator)
         try:
             await self.get_response(request)
@@ -24,6 +36,8 @@ class SignaldAPI(SignaldGeneratedAPI):
         """
         Starts receiving messages for the account identified by the argument
         username (a phone number).
+
+        :param username: Phone number of the account.
         """
         await self.get_response_and_wait_for(
             request={"type": "subscribe", "username": username},
@@ -34,43 +48,29 @@ class SignaldAPI(SignaldGeneratedAPI):
     async def unsubscribe(self, username: str):
         """
         Stops receiving message for an phone 'username'.
+
+        :param username: Phone number of the account.
         """
         await self.get_response({"type": "unsubscribe", "username": username})
 
-    async def link(
-        self, deviceName: str, username: str
-    ) -> typing.Tuple[str, asyncio.Future]:
-        """
-        Link signald to an existing signal account.
-
-        Return a URI that needs to be converted to a QR code to be scanned with
-        the official signal app, and a future which result is set to True once the
-        link is successful.
-        """
-        linking_successful = self.get_future_for(
-            lambda response: response.get("type") == "linking_successful"
-            and response.get("data", dict()).get("username") == username
-        )
-        try:
-            response = await self.get_response(
-                {"type": "link", "deviceName": deviceName}
-            )
-        except SignaldException:
-            self.specific_handlers.remove(linking_successful.handler)
-            linking_successful.cancel()
-            raise
-        else:
-            uri = response.get("uri")
-            return uri, linking_successful
-
     async def verify(self, username: str, code: str):
+        """
+        Completes the registration process with the SMS code
+
+        :param username: Phone number of the account.
+        :param code: The code received by SMS.
+        """
         await self.get_response({"type": "verify", "username": username, "code": code})
 
     async def register(self, username: str, captcha: str = None):
         """
         Register signald as the primary signal device for a phone number.
-        To complete to process, the SignaldAPI.verify coroutine must then be
-        awaited with the code received by SMS.
+        To complete to process, the :func:`SignaldAPI.verify` coroutine
+        must then be awaited with the code received by SMS.
+
+        :param username: Phone number of the account.
+        :param captcha: Might be needed. Checked the `signald wiki <https://gitlab.com/signald/signald/-/wikis/Captchas>`_
+            for more info.
         """
         payload = {"type": "register", "username": username}
         if captcha is not None:
@@ -78,6 +78,9 @@ class SignaldAPI(SignaldGeneratedAPI):
         await self.get_response(payload)
 
     async def list_accounts(self) -> JsonAccountListv0:
+        """
+        List the signald accounts.
+        """
         data = await self.get_response({"type": "list_accounts"})
         return JsonAccountListv0(**data)
 
@@ -85,5 +88,9 @@ class SignaldAPI(SignaldGeneratedAPI):
         envelope = JsonMessageEnvelopev1(**payload.get("data", dict()))
         self.handle_envelope(envelope)
 
-    def handle_envelope(self, envelope):
+    def handle_envelope(self, envelope: JsonMessageEnvelopev1):
+        """
+        Called when receiving a message after being subscribed.
+        Override this method to trigger events when receiving messages, typing notifications, etc.
+        """
         print(envelope)
