@@ -21,6 +21,8 @@ def raise_error(response: dict):
     data = response.get("data", dict())
     if isinstance(data, list):
         error = response.get("error", False)
+    elif isinstance(data, str):  # captcha_required, for instance
+        error = False
     else:
         error = response.get("error", data.get("error", False))
     if error:
